<?php

declare(strict_types=1);

namespace Dedi\SyliusVoucherPlugin\Controller\Action;

use Dedi\SyliusVoucherPlugin\Model\VoucherBalanceCollection;
use Dedi\SyliusVoucherPlugin\Repository\VoucherRepositoryInterface;
use FOS\RestBundle\View\View;
use FOS\RestBundle\View\ViewHandlerInterface;
use Symfony\Component\HttpFoundation\Request;
use Symfony\Component\HttpFoundation\Response;

/**
 * The purpose of this class is to show the voucher balance, i.e. what amount is still available on enabled vouchers
 */
final class VoucherBalanceAction
{
    /** @var VoucherRepositoryInterface */
    private $voucherRepository;

    /** @var ViewHandlerInterface */
    private $viewHandler;

    public function __construct(
        VoucherRepositoryInterface $voucherRepository,
        ViewHandlerInterface $viewHandler
    ) {
        $this->voucherRepository = $voucherRepository;
        $this->viewHandler = $viewHandler;
    }

    public function __invoke(Request $request): Response
    {
        $voucherBalanceCollection = VoucherBalanceCollection::createFromVouchers(
            $this->voucherRepository->findEnabledNotExpired()
        );

        $view = View::create();
        $view
            ->setTemplate('@DediSyliusVoucherPlugin/Admin/voucherBalance.html.twig')
            ->setData([
                'voucherBalanceCollection' => $voucherBalanceCollection,
            ])
        ;

        return $this->viewHandler->handle($view);
    }
}
